devicesinlan - Turulomio

# NAME

devicesinlan: Analyse tous les appareils de votre LAN. Ensuite, vous pouvez définir un alias pour vos appareils connus afin de détecter de futurs appareils étranges dans votre réseau.

# SYNOPSIS

devicesinlan [-h] [--version] [--method {PingArp,ScapyArping,Scapy}] [--interface INTERFACE | --add | --remove | --list | --load LOAD | --save SAVE | --reset] [--debug DEBUG]

# LA DESCRIPTION

Si vous lancez DevicesInLan sans paramètres, un assistant de console est lancé.

De plus, vous pouvez utiliser l'un de ces paramètres.

--interface

Analyse le réseau du paramètre d'interface et imprime une liste des appareils détectés.

Si un appareil n'est pas connu, il sera affiché en rouge. Les appareils en vert sont des appareils de confiance.

--add

Permet d'ajouter un appareil connu depuis la console.

--remove

Permet de supprimer un appareil connu depuis la console.

--list

Affiche tous les appareils connus dans la base de données depuis la console.

--load

Charge une liste d'appareils connus au format xml.

--save

Enregistre la liste des appareils connus dans un fichier xml.

--debug

Donne des informations de débogage lors de l'exécution de DevicesInLAN. C'est désactivé par défaut

Le paramètre peut prendre ces options : CRITICAL, ERROR, WARNING, INFO, DEBUG.

--reset

Supprime tous les appareils connus.

# MÉTHODES DE BALAYAGE

DevicesInLan peut utiliser plusieurs méthodes pour rechercher des appareils. Il vous suffit d'ajouter le --method en mode console.

PingArp

Il essaie d'établir une connexion socket avec n'importe quel appareil du réseau local. Ensuite, il recherche avec la commande 'arp' les informations mac

La méthode PingArp est utilisée par défaut dans les versions Windows et Linux.

Scapy

Utilise Scapy pour créer une requête ARP et capturer sa réponse pour chaque ip du sous-réseau afin d'obtenir des informations sur les macs.

Cette méthode peut être utilisée dans les versions Windows et Linux, mais elle doit être exécutée avec le rôle d'administrateur.

De plus, vous devez installer 'npcap' pour l'exécuter sous Windows.

ScapyArping

Utilise la fonction arping de Scapy pour créer une requête ARP et capturer sa réponse pour chaque ip du sous-réseau afin d'obtenir des informations sur les macs.

Cette méthode peut être utilisée dans les versions Windows et Linux, mais elle doit être exécutée avec le rôle d'administrateur.

De plus, vous devez installer 'npcap' pour l'exécuter sous Windows.

# EXEMPLES

devicesinlan

Commande par défaut. Il utilise la méthode PingArp.

devicesinlan --method ScapyArping

Il utilise la méthode ScapyArping.

Created with libmangenerator at 2025-12-28